package cn.com.infosec.asn1.x9;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.math.ec.ECCurve;
import java.math.BigInteger;

public class X9Curve extends ASN1Encodable implements X9ObjectIdentifiers {
   private ECCurve curve;
   private byte[] seed;
   private DERObjectIdentifier fieldIdentifier = null;

   public X9Curve(ECCurve curve) {
      this.curve = curve;
      this.seed = null;
      this.setFieldIdentifier();
   }

   public X9Curve(ECCurve curve, byte[] seed) {
      this.curve = curve;
      this.seed = seed;
      this.setFieldIdentifier();
   }

   public X9Curve(X9FieldID fieldID, ASN1Sequence seq) {
      if ((this.fieldIdentifier = fieldID.getIdentifier()).equals(X9ObjectIdentifiers.prime_field)) {
         BigInteger fieldID1 = ((DERInteger)fieldID.getParameters()).getValue();
         X9FieldElement var3;
         var3 = new X9FieldElement.<init>(fieldID1, (ASN1OctetString)seq.getObjectAt(0));
         X9FieldElement var4;
         var4 = new X9FieldElement.<init>(fieldID1, (ASN1OctetString)seq.getObjectAt(1));
         BigInteger var10003 = fieldID1;
         fieldID1 = var3.getValue().toBigInteger();
         this.curve = new ECCurve.Fp(var10003, fieldID1, var4.getValue().toBigInteger());
      } else if (this.fieldIdentifier.equals(X9ObjectIdentifiers.characteristic_two_field)) {
         DERSequence fieldID2;
         DERSequence var10000 = fieldID2 = (DERSequence)fieldID.getParameters();
         int var12 = ((DERInteger)var10000.getObjectAt(0)).getValue().intValue();
         DERObjectIdentifier var17 = (DERObjectIdentifier)var10000.getObjectAt(1);
         int var14 = 0;
         int var5 = 0;
         int fieldID3;
         if (var17.equals(X9ObjectIdentifiers.tpBasis)) {
            fieldID3 = ((DERInteger)fieldID2.getObjectAt(2)).getValue().intValue();
         } else {
            var10000 = (DERSequence)fieldID2.getObjectAt(2);
            fieldID3 = ((DERInteger)var10000.getObjectAt(0)).getValue().intValue();
            var14 = ((DERInteger)var10000.getObjectAt(1)).getValue().intValue();
            var5 = ((DERInteger)var10000.getObjectAt(2)).getValue().intValue();
         }

         X9FieldElement var6;
         X9FieldElement var10001 = var6 = new X9FieldElement;
         ASN1OctetString var7 = (ASN1OctetString)seq.getObjectAt(0);
         var10001.<init>(var12, fieldID3, var14, var5, var7);
         X9FieldElement var16;
         var10001 = var16 = new X9FieldElement;
         ASN1OctetString var8 = (ASN1OctetString)seq.getObjectAt(1);
         var10001.<init>(var12, fieldID3, var14, var5, var8);
         int var18 = var12;
         BigInteger var13 = var6.getValue().toBigInteger();
         BigInteger var15 = var16.getValue().toBigInteger();
         this.curve = new ECCurve.F2m(var18, fieldID3, var14, var5, var13, var15);
      }

      if (seq.size() == 3) {
         this.seed = ((DERBitString)seq.getObjectAt(2)).getBytes();
      }

   }

   private void setFieldIdentifier() {
      ECCurve var1;
      if ((var1 = this.curve) instanceof ECCurve.Fp) {
         this.fieldIdentifier = X9ObjectIdentifiers.prime_field;
      } else {
         if (!(var1 instanceof ECCurve.F2m)) {
            throw new IllegalArgumentException("This type of ECCurve is not implemented");
         }

         this.fieldIdentifier = X9ObjectIdentifiers.characteristic_two_field;
      }

   }

   public ECCurve getCurve() {
      return this.curve;
   }

   public byte[] getSeed() {
      return this.seed;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      if (this.fieldIdentifier.equals(X9ObjectIdentifiers.prime_field)) {
         var1.add((new X9FieldElement(this.curve.getA())).getDERObject());
         var1.add((new X9FieldElement(this.curve.getB())).getDERObject());
      } else if (this.fieldIdentifier.equals(X9ObjectIdentifiers.characteristic_two_field)) {
         var1.add((new X9FieldElement(this.curve.getA())).getDERObject());
         var1.add((new X9FieldElement(this.curve.getB())).getDERObject());
      }

      if (this.seed != null) {
         var1.add(new DERBitString(this.seed));
      }

      return new DERSequence(var1);
   }
}
